erase_bytes

Function erase_bytes 

pub fn erase_bytes(slice: &mut [u8])
To ensure keys and other valuable bits of info don’t linger in memory, this function is called when possible to zero out the memory referred to in slice.